macro_rules! with_timeout {
($test_body:expr) => { ... };
}Expand description
Macro to wrap test bodies with timeout to prevent hanging tests
macro_rules! with_timeout {
($test_body:expr) => { ... };
}Macro to wrap test bodies with timeout to prevent hanging tests